aboutsummaryrefslogtreecommitdiffstats
path: root/packages/contracts/test/exchange/core.ts
diff options
context:
space:
mode:
authorGreg Hysen <greg.hysen@gmail.com>2018-03-20 01:56:21 +0800
committerAmir Bandeali <abandeali1@gmail.com>2018-04-21 04:56:17 +0800
commit1efba5979f2c11aa70845d2ef9f32b60e1bc6971 (patch)
tree609a7e9ddadad83435b6df93d52dabef73f249b2 /packages/contracts/test/exchange/core.ts
parentbf3c4f47432228a53cf2309688be5efc348026c3 (diff)
downloaddexon-0x-contracts-1efba5979f2c11aa70845d2ef9f32b60e1bc6971.tar
dexon-0x-contracts-1efba5979f2c11aa70845d2ef9f32b60e1bc6971.tar.gz
dexon-0x-contracts-1efba5979f2c11aa70845d2ef9f32b60e1bc6971.tar.bz2
dexon-0x-contracts-1efba5979f2c11aa70845d2ef9f32b60e1bc6971.tar.lz
dexon-0x-contracts-1efba5979f2c11aa70845d2ef9f32b60e1bc6971.tar.xz
dexon-0x-contracts-1efba5979f2c11aa70845d2ef9f32b60e1bc6971.tar.zst
dexon-0x-contracts-1efba5979f2c11aa70845d2ef9f32b60e1bc6971.zip
Renamed all instances of timestamp to salt. Clarified test case wording.
Diffstat (limited to 'packages/contracts/test/exchange/core.ts')
-rw-r--r--packages/contracts/test/exchange/core.ts30
1 files changed, 15 insertions, 15 deletions
diff --git a/packages/contracts/test/exchange/core.ts b/packages/contracts/test/exchange/core.ts
index ac8192d25..53863c5d8 100644
--- a/packages/contracts/test/exchange/core.ts
+++ b/packages/contracts/test/exchange/core.ts
@@ -743,30 +743,30 @@ describe('Exchange', () => {
});
describe('cancelOrdersBefore', () => {
- it('should fail to set timestamp less than existing CancelBefore timestamp', async () => {
- const timestamp = new BigNumber(1);
- await exWrapper.cancelOrdersBeforeAsync(timestamp, makerAddress);
- const lesser_timestamp = new BigNumber(0);
+ it('should fail to set makerEpoch less than current makerEpoch', async () => {
+ const makerEpoch = new BigNumber(1);
+ await exWrapper.cancelOrdersBeforeAsync(makerEpoch, makerAddress);
+ const lesserMakerEpoch = new BigNumber(0);
return expect(
- exWrapper.cancelOrdersBeforeAsync(lesser_timestamp, makerAddress),
+ exWrapper.cancelOrdersBeforeAsync(lesserMakerEpoch, makerAddress),
).to.be.rejectedWith(constants.REVERT);
});
- it('should fail to set timestamp equal to existing CancelBefore timestamp', async () => {
- const timestamp = new BigNumber(1);
- await exWrapper.cancelOrdersBeforeAsync(timestamp, makerAddress);
+ it('should fail to set makerEpoch equal to existing makerEpoch', async () => {
+ const makerEpoch = new BigNumber(1);
+ await exWrapper.cancelOrdersBeforeAsync(makerEpoch, makerAddress);
return expect(
- exWrapper.cancelOrdersBeforeAsync(timestamp, makerAddress),
+ exWrapper.cancelOrdersBeforeAsync(makerEpoch, makerAddress),
).to.be.rejectedWith(constants.REVERT);
});
- it('should cancel only orders with a timestamp less than CancelBefore timestamp', async () => {
- // Cancel all transactions with a timestamp less than 1
- const timestamp = new BigNumber(1);
- await exWrapper.cancelOrdersBeforeAsync(timestamp, makerAddress);
+ it('should cancel only orders with a makerEpoch less than existing makerEpoch', async () => {
+ // Cancel all transactions with a makerEpoch less than 1
+ const makerEpoch = new BigNumber(1);
+ await exWrapper.cancelOrdersBeforeAsync(makerEpoch, makerAddress);
- // Create 3 orders with timestamps 0,1,2
- // Since we cancelled with timestamp=1, orders with timestamp<1 will not be processed
+ // Create 3 orders with makerEpoch values: 0,1,2
+ // Since we cancelled with makerEpoch=1, orders with makerEpoch<1 will not be processed
balances = await dmyBalances.getAsync();
const signedOrders = await Promise.all([
orderFactory.newSignedOrder({